# Technological Exploration: <descriptive title of exploration challenge>

- [Technological Exploration: ](#technological-exploration-)
- [Prompt to identify and specify the major relevant technological building blocks](#prompt-to-identify-and-specify-the-major-relevant-technological-building-blocks)
- [further define and refine technical decisions prompt](#further-define-and-refine-technical-decisions-prompt)

# Prompt to identify and specify the major relevant technological building blocks
given the vision statement of <...>
```
```

and given the business goal of <...>
```
```

and given the customer profile <...>
```
```

and given the targeted capabilities <...>
```
```

and given the targeted key features <...>
```
```

and given further known functional requirements
```
* list of known functional requirements if any
```

and given further known non functional requirements
```
* list of known non functional requirements if any
```

and given any upfront decided technical constraint
```
```

and given the specified design concept
```
```

create a list of our most important technical constraints and decisions by using the following format template:
```
# Title: <descriptive title of the set of choosen technologies>

- [Title: ](#title-)
- [Decision for allowed implementation languges](#decision-for-allowed-implementation-languges)
- [Decision for used application frameworks](#decision-for-used-application-frameworks)
- [Decision for used test frameworks](#decision-for-used-test-frameworks)
- [Decision for used infrastructure](#decision-for-used-infrastructure)
- [Decision for ](#decision-for-)

# Decision for allowed implementation languges
<list of languge>: <purpose and value>

# Decision for used application frameworks
<list of application frameworks>: <purpose and value>

# Decision for used test frameworks
<list of test frameworks>: <purpose and value>

# Decision for used infrastructure
<list of relevant infrastructure decisions>: <purpose and value>

# Decision for <descriptive name of further technical aspects>
<list of further technical aspects>: <purpose and value>

```

Explain why technical decisions contribute perfectly to the list of the given constraints.

# further define and refine technical decisions prompt
...
